@@ -5,6 +5,7 @@
 #include <dbus/dbus.h>
 #include <glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
+#include "test/lib/util.h"
 
 DBusConnection *bus;
 GMainContext *main_context;
@@ -44,6 +45,7 @@ send_and_allow_reentry (DBusConnection * bus, DBusMessage * message)
   g_main_loop_run  (closure.loop);
 
   g_main_loop_unref (closure.loop);
+  dbus_pending_call_unref (pending);
   return closure.reply;
 }
 
@@ -56,7 +58,7 @@ main(int argc, const char *argv[])
 
   main_context = g_main_context_new ();
   dbus_error_init (&error);
-  bus = dbus_bus_get (DBUS_BUS_SESSION, &error);
+  bus = dbus_bus_get_private (DBUS_BUS_SESSION, &error);
   if (!bus)
   {
     fprintf(stderr, "Couldn't connect to bus: %s\n", error.name);
@@ -93,6 +95,15 @@ main(int argc, const char *argv[])
     fprintf(stderr, "Sorry; can't communicate: %s\n", error.message);
     exit(1);
   }
+  dbus_message_unref (reply);
+  dbus_message_unref (message);
+
+  test_run_until_disconnected (dbus_connection_get_g_connection (bus),
+                               NULL);
+  dbus_connection_unref (bus);
+
+  dbus_shutdown ();
+  g_main_context_unref (main_context);
 
   return 0;
 }
