@@ -116,7 +116,8 @@ void my_object_async_increment (MyObject *obj, gint32 x, DBusGMethodInvocation *
 
 void my_object_async_throw_error (MyObject *obj, DBusGMethodInvocation *context);
 
-void my_object_unsafe_disable_legacy_property_access (MyObject *obj);
+gboolean my_object_unsafe_disable_legacy_property_access (MyObject *obj,
+    GError **error);
 
 void my_object_emit_objectified (MyObject *obj, GObject *other);
 
